@@ -1,6 +1,6 @@
 #' @keywords internal
 #' @noRd
-"_PACKAGE"
+'_PACKAGE'
 
 ## usethis namespace: start
 #' @importFrom cli col_blue col_green
@@ -12,7 +12,7 @@
 #' @importFrom readr read_file write_file
 #' @importFrom rstudioapi openProject
 #' @importFrom stringr str_replace str_to_lower
-#' @importFrom usethis ui_done ui_info ui_oops ui_todo ui_yeah
+#' @importFrom usethis ui_done ui_info ui_oops ui_todo ui_warn ui_yeah
 #' @importFrom utils download.file menu
 #' @importFrom yaml read_yaml write_yaml
 ## usethis namespace: end
